"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("@jfrog-pipelines/logger");
const StepServiceDataAdapter_1 = require("../../../driven/acl/step-service/StepServiceDataAdapter");
const StepServiceRepository_1 = require("../StepServiceRepository");
jest.mock('@jfrog-pipelines/configuration', () => ({
    ConfigFactory: {
        config: {
            rtUiUrl: 'http://example.com'
        }
    }
}));
jest.mock('@jfrog-pipelines/logger', () => {
    const actualTracker = jest.requireActual('@jfrog-pipelines/logger');
    return {
        ...actualTracker,
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
describe('StepServiceRepository Tests', () => {
    const stepId = 1;
    const stepServiceRepository = new StepServiceRepository_1.StepServiceRepository(stepId);
    it('should be defined', () => {
        expect(stepServiceRepository).toBeDefined();
    });
    describe('getStepletIdsByStepId Tests', () => {
        it('should return stepletIds by stepId', async () => {
            const getStepletIdsByStepIdSpied = jest
                .spyOn(StepServiceDataAdapter_1.StepServiceDataAdapter.prototype, 'getStepletsByStepId')
                .mockResolvedValueOnce([
                { id: 1, stepId: 1 },
                { id: 2, stepId: 2 }
            ]);
            const stepId = 1;
            await stepServiceRepository.getStepletIdsByStepId(stepId);
            expect(getStepletIdsByStepIdSpied).toHaveBeenCalledTimes(1);
        });
        it('should return empty array if cannot find steplets by stepId', async () => {
            const getStepletIdsByStepIdSpied = jest
                .spyOn(StepServiceDataAdapter_1.StepServiceDataAdapter.prototype, 'getStepletsByStepId')
                .mockRejectedValueOnce('error');
            const stepId = 1;
            const response = await stepServiceRepository.getStepletIdsByStepId(stepId);
            expect(getStepletIdsByStepIdSpied).toHaveBeenCalledTimes(1);
            expect(response).toStrictEqual([]);
            expect(logger.warn).toHaveBeenCalledWith("Cannot find stepletIds for the stepId:1. Error:'error'");
        });
    });
    describe('getArtifactoryUrlsByStepId Tests', () => {
        it('should return newArtifactoryUrl value object', async () => {
            const mockedValue = { test: 'file' };
            const getArtifactoryUrlByStepIdSpied = jest
                .spyOn(StepServiceDataAdapter_1.StepServiceDataAdapter.prototype, 'getArtifactoryUrlByStepId')
                .mockResolvedValueOnce(mockedValue);
            const stepId = 1;
            const artifactName = 'artifactName';
            await stepServiceRepository.getArtifactoryUrlsByStepId(stepId, artifactName);
            expect(getArtifactoryUrlByStepIdSpied).toHaveBeenCalledTimes(1);
        });
        it('should return null if it cannot get Artifactory URls', async () => {
            jest.spyOn(StepServiceDataAdapter_1.StepServiceDataAdapter.prototype, 'getArtifactoryUrlByStepId').mockRejectedValueOnce('error');
            const stepId = 1;
            const artifactName = 'artifactName';
            await stepServiceRepository.getArtifactoryUrlsByStepId(stepId, artifactName);
            expect(logger.warn).toHaveBeenCalledWith("Cannot get Artifactory Urls. Error:, 'error'");
        });
    });
    describe('markConsoleArchived Tests', () => {
        it('should update Console Archived', async () => {
            const updateConsoleArchivedSpied = jest
                .spyOn(StepServiceDataAdapter_1.StepServiceDataAdapter.prototype, 'updateConsoleArchived')
                .mockResolvedValueOnce();
            const stepletId = 1;
            await stepServiceRepository.markConsoleArchived(stepletId);
            expect(updateConsoleArchivedSpied).toHaveBeenCalledTimes(1);
        });
        it('should give warning logs if stepServiceDataAdapter returns error', async () => {
            jest.spyOn(StepServiceDataAdapter_1.StepServiceDataAdapter.prototype, 'updateConsoleArchived').mockRejectedValueOnce('error');
            const stepletId = 1;
            await stepServiceRepository.markConsoleArchived(stepletId);
            expect(logger.warn).toHaveBeenLastCalledWith("Cannot update consoleArchived value to error for stepletId: 1 due to error: 'error'");
        });
    });
    describe('getStepById Tests', () => {
        it('should get step by id', async () => {
            const mockStepData = {
                id: 1,
                statusCode: 4008
            };
            const stepId = 1;
            const getStepByIdSpied = jest
                .spyOn(StepServiceDataAdapter_1.StepServiceDataAdapter.prototype, 'getStepById')
                .mockResolvedValueOnce(mockStepData);
            const result = await stepServiceRepository.getStepById(stepId);
            expect(getStepByIdSpied).toHaveBeenCalledTimes(1);
            expect(getStepByIdSpied).toHaveBeenCalledWith(stepId);
            expect(result).toStrictEqual(mockStepData);
        });
        it('should give warning logs if step could not be fetched', async () => {
            const mockError = 'error';
            jest.spyOn(StepServiceDataAdapter_1.StepServiceDataAdapter.prototype, 'getStepById').mockRejectedValueOnce(mockError);
            const stepId = 1;
            await stepServiceRepository.getStepById(stepId);
            expect(logger.warn).toHaveBeenLastCalledWith(`failed to fetch step for stepId: ${stepId} due to error: '${mockError}'`);
        });
    });
});
//# sourceMappingURL=StepServiceRepository.test.js.map