"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("@jfrog-pipelines/logger");
const FileStoreRepository_1 = require("../FileStoreRepository");
const FileSystemAdapter_1 = require("../../../../driven/FileSystemAdapter");
const ArtifactoryAdapter_1 = require("../../../../driven/ArtifactoryAdapter");
jest.mock('@jfrog-pipelines/logger', () => {
    return {
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                warn: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
jest.mock('../ArtifactoryFileStrategy', () => {
    return {
        ArtifactoryFileStrategy: jest.fn().mockImplementation(() => {
            return {
                appendExecutionLogs: jest.fn()
            };
        })
    };
});
describe('FileStoreRepository Tests', () => {
    const stepId = 1;
    const fileStoreRepository = new FileStoreRepository_1.FileStoreRepository(stepId);
    it('should set strategy', () => {
        const strategy = 'mockStrategy';
        fileStoreRepository.setStrategy(strategy);
        expect(fileStoreRepository).toBeDefined();
    });
    describe('cleanTempFolder tests', () => {
        it('should cleanTempFolder', async () => {
            const clearTemporaryFolderSpied = jest
                .spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'clearTempFolder')
                .mockResolvedValueOnce();
            await fileStoreRepository.cleanTempFolder();
            expect(clearTemporaryFolderSpied).toHaveBeenCalledTimes(1);
        });
        it('should log warning if it cannot clear temp folder', async () => {
            jest.spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'clearTempFolder').mockRejectedValueOnce('error');
            await fileStoreRepository.cleanTempFolder();
            expect(logger.warn).toHaveBeenCalledWith("Cannot clear temp folder. error: 'error'");
        });
    });
    describe('createLogFile Tests', () => {
        it('should createLogFile', async () => {
            const stepletId = 1;
            const createFileSpied = jest.spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'createFile').mockResolvedValueOnce('test');
            const result = await fileStoreRepository.createLogFile(stepletId);
            expect(createFileSpied).toHaveBeenCalledTimes(1);
            expect(result).toStrictEqual('test');
        });
    });
    describe('appendStepConsoles Tests', () => {
        it('should append step consoles', async () => {
            const filePath = 'testPath';
            const stepConsoleLogs = {
                consoleId: 'testConsoleId',
                stepId: 1,
                pipelineId: 1,
                isShown: true,
                isSuccess: true,
                stage: 'cleanup',
                message: 'cleanup'
            };
            const writeLogsToFileSpied = jest
                .spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'writeLogsToFile')
                .mockResolvedValueOnce(true);
            await fileStoreRepository.appendStepConsoles(filePath, stepConsoleLogs);
            expect(writeLogsToFileSpied).toHaveBeenCalledTimes(1);
        });
        it('appendStepConsoles should log warning if writeLogsToFile fails', async () => {
            const filePath = 'testPath';
            const stepConsoleLogs = {
                consoleId: 'testConsoleId',
                stepId: 1,
                pipelineId: 1,
                isShown: true,
                isSuccess: true,
                stage: 'cleanup',
                message: 'cleanup'
            };
            jest.spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'writeLogsToFile').mockRejectedValueOnce('error');
            await fileStoreRepository.appendStepConsoles(filePath, stepConsoleLogs);
            expect(logger.warn).toHaveBeenCalledWith("Cannot add step logs to file. Error:'error'");
        });
    });
    describe('appendCleanupConsoles Tests', () => {
        it('should appendCleanupConsoles', async () => {
            const filePath = 'testPath';
            const stepletSetupAndCleanUpLogs = new Map();
            stepletSetupAndCleanUpLogs.set('cleanup', [
                {
                    consoleId: 'testConsoleId',
                    stepletId: 1,
                    pipelineId: 1,
                    isShown: true,
                    isSuccess: true,
                    stage: 'cleanup',
                    message: 'cleanup'
                }
            ]);
            const writeLogsToFileSpied = jest
                .spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'writeLogsToFile')
                .mockResolvedValueOnce(true);
            await fileStoreRepository.appendCleanupConsoles(filePath, stepletSetupAndCleanUpLogs);
            expect(writeLogsToFileSpied).toHaveBeenCalledTimes(1);
        });
        it('should appendCleanupConsoles even if the stepletSetupAndCleanUpLogs are empty', async () => {
            const filePath = 'testPath';
            const stepletSetupAndCleanUpLogs = new Map();
            stepletSetupAndCleanUpLogs.set('', []);
            const writeLogsToFileSpied = jest
                .spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'writeLogsToFile')
                .mockResolvedValueOnce(true);
            await fileStoreRepository.appendCleanupConsoles(filePath, stepletSetupAndCleanUpLogs);
            expect(writeLogsToFileSpied).toHaveBeenCalledTimes(1);
        });
        it('should log warning if it cannot append cleanup logs due to any error from the fileSystemAdapter', async () => {
            const filePath = 'testPath';
            const stepletSetupAndCleanUpLogs = new Map();
            stepletSetupAndCleanUpLogs.set('cleanup', [{}]);
            const writeLogsToFileSpied = jest
                .spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'writeLogsToFile')
                .mockRejectedValueOnce('error');
            await fileStoreRepository.appendCleanupConsoles(filePath, stepletSetupAndCleanUpLogs);
            expect(writeLogsToFileSpied).toHaveBeenCalledTimes(1);
            expect(logger.warn).toHaveBeenCalledWith("Cannot add cleanup logs to file. Error:'error'");
        });
    });
    describe('appendSetupConsoles Tests', () => {
        it('should appendSetupConsoles', async () => {
            const filePath = 'testPath';
            const stepletSetupAndCleanUpLogs = new Map();
            stepletSetupAndCleanUpLogs.set('setup', [
                {
                    consoleId: 'testConsoleId',
                    stepletId: 1,
                    pipelineId: 1,
                    isShown: true,
                    isSuccess: true,
                    stage: 'setup',
                    message: 'setup'
                }
            ]);
            const writeLogsToFileSpied = jest
                .spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'writeLogsToFile')
                .mockResolvedValueOnce(true);
            await fileStoreRepository.appendSetupConsoles(filePath, stepletSetupAndCleanUpLogs);
            expect(writeLogsToFileSpied).toHaveBeenCalledTimes(1);
        });
        it('should appendStepConsoles even if the stepletSetupAndCleanUpLogs are empty', async () => {
            const filePath = 'testPath';
            const stepletSetupAndCleanUpLogs = {
                consoleId: 'testConsoleId',
                stepId: 1,
                pipelineId: 1,
                isShown: true,
                isSuccess: true,
                stage: 'setup',
                message: 'setup'
            };
            const writeLogsToFileSpied = jest
                .spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'writeLogsToFile')
                .mockResolvedValueOnce(true);
            await fileStoreRepository.appendStepConsoles(filePath, stepletSetupAndCleanUpLogs);
            expect(writeLogsToFileSpied).toHaveBeenCalledTimes(1);
        });
        it('should log warning if it cannot append step logs due to any error from the fileSystemAdapter', async () => {
            const filePath = 'testPath';
            const stepletSetupAndCleanUpLogs = new Map();
            stepletSetupAndCleanUpLogs.set('step', [{}]);
            const writeLogsToFileSpied = jest
                .spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'writeLogsToFile')
                .mockRejectedValueOnce('error');
            await fileStoreRepository.appendSetupConsoles(filePath, stepletSetupAndCleanUpLogs);
            expect(writeLogsToFileSpied).toHaveBeenCalledTimes(1);
            expect(logger.warn).toHaveBeenCalledWith("Cannot add setup logs to file. Error:'error'");
        });
    });
    describe('deleteFile Tests', () => {
        it('should deleteFile if path is provided', async () => {
            const filePath = 'testPath';
            const deleteFileSpied = jest.spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'deleteFile').mockResolvedValueOnce();
            await fileStoreRepository.deleteFile(filePath);
            expect(deleteFileSpied).toHaveBeenCalledTimes(1);
        });
    });
    describe('appendExecutionLogs Tests', () => {
        it('should append execution logs', async () => {
            const filePath = `${__dirname}/sample.txt`;
            const getUrl = 'url';
            const token = 'token';
            const stepletId = 1;
            const appendExecutionLogsMock = jest.fn();
            const strategyMock = {
                appendExecutionLogs: appendExecutionLogsMock
            };
            fileStoreRepository.setStrategy(strategyMock);
            await fileStoreRepository.appendExecutionLogs(filePath, getUrl, token, stepletId);
            expect(appendExecutionLogsMock).toHaveBeenCalledWith(filePath, getUrl, token, stepletId);
        });
    });
    describe('uploadToArtifactory Tests', () => {
        it('should log a warning if rtAdapter returns an error during upload', async () => {
            const errorMessage = 'error';
            const filePath = 'testPath';
            const putUrl = 'url';
            const readStreamMock = { pipe: jest.fn() };
            jest.spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'getReadStream').mockReturnValueOnce(readStreamMock);
            jest.spyOn(ArtifactoryAdapter_1.ArtifactoryAdapter.prototype, 'upload').mockRejectedValueOnce(errorMessage);
            await fileStoreRepository.uploadToArtifactory(filePath, putUrl, 'token');
            expect(logger.warn).toHaveBeenCalledWith(`Cannot upload to artifactory. Error:'${errorMessage}'`);
        });
        it('should upload the compressed stream of logs to Artifactory', async () => {
            const filePath = 'testPath';
            const putUrl = 'url';
            const token = 'token';
            const readStreamMock = { pipe: jest.fn() };
            const fileAdapterMock = jest
                .spyOn(FileSystemAdapter_1.FileSystemAdapter.prototype, 'getReadStream')
                .mockReturnValueOnce(readStreamMock);
            jest.spyOn(ArtifactoryAdapter_1.ArtifactoryAdapter.prototype, 'upload').mockResolvedValueOnce();
            await fileStoreRepository.uploadToArtifactory(filePath, putUrl, token);
            expect(fileAdapterMock).toHaveBeenCalledWith(filePath);
            fileAdapterMock.mockClear();
        });
    });
});
//# sourceMappingURL=FileStoreRepository.test.js.map