"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const promises_1 = __importDefault(require("node:fs/promises"));
const node_fs_1 = __importDefault(require("node:fs"));
const node_os_1 = __importDefault(require("node:os"));
const node_path_1 = __importDefault(require("node:path"));
const node_stream_1 = require("node:stream");
const rimraf_1 = require("rimraf");
const logger_1 = require("@jfrog-pipelines/logger");
const FileSystemAdapter_1 = require("../FileSystemAdapter");
jest.mock('node:fs/promises');
jest.mock('node:os');
jest.mock('node:path');
jest.mock('@jfrog-pipelines/logger', () => {
    const actualTracker = jest.requireActual('@jfrog-pipelines/logger');
    return {
        ...actualTracker,
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            })
        }
    };
});
const logger = logger_1.LoggerFactory.getLogger();
function readFileContent(filePath) {
    return new Promise((resolve, reject) => {
        node_fs_1.default.readFile(filePath, 'utf8', (error, data) => {
            if (error) {
                reject(error);
            }
            else {
                resolve(data);
            }
        });
    });
}
const TWO = 2;
describe('FileSystemAdapter Tests', () => {
    const stepId = 1;
    const fileAdapter = new FileSystemAdapter_1.FileSystemAdapter(stepId);
    it('should be defined', () => {
        expect(fileAdapter).toBeDefined();
    });
    describe('createFile tests', () => {
        it('should create an empty text file in the temp folder', async () => {
            const stepletId = 1;
            const expectedFileName = `${stepletId}_log.txt`;
            jest.spyOn(node_os_1.default, 'tmpdir').mockReturnValueOnce('/tmp');
            jest.spyOn(node_path_1.default, 'join').mockReturnValueOnce(`/tmp/${expectedFileName}`);
            const expectedFilePath = `/tmp/${expectedFileName}`;
            const result = await fileAdapter.createFile(stepletId);
            expect(result).toBe(expectedFilePath);
            expect(promises_1.default.open).toHaveBeenCalledWith(expectedFilePath, 'a');
            expect(logger.debug).toHaveBeenCalledWith(`${expectedFilePath} file created`);
        });
        it('should log warning if it cannot create file', async () => {
            const stepletId = 123;
            jest.spyOn(promises_1.default, 'open').mockRejectedValue(new Error('Failed to create file'));
            const expectedFileName = `${stepletId}_log.txt`;
            jest.spyOn(node_os_1.default, 'tmpdir').mockReturnValueOnce('/tmp');
            jest.spyOn(node_path_1.default, 'join').mockReturnValueOnce(`/tmp/${expectedFileName}`);
            const fileSystemAdapter = new FileSystemAdapter_1.FileSystemAdapter(stepletId);
            const result = await fileSystemAdapter.createFile(stepletId);
            expect(result).toBeNull();
            expect(logger.warn).toHaveBeenLastCalledWith(`Cannot create /tmp/123_log.txt`);
        });
    });
    describe('deleteFile tests', () => {
        it('should deleteFile when filepath is provided', async () => {
            const filePath = '/tmp';
            await fileAdapter.deleteFile(filePath);
            expect(promises_1.default.unlink).toHaveBeenCalledWith(filePath);
            expect(logger.debug).toHaveBeenCalledWith(`${filePath} deleted successfully`);
        });
        it('should log warning if file could not be deleted', async () => {
            const filePath = '/tmp';
            jest.spyOn(promises_1.default, 'unlink').mockRejectedValue(new Error('Failed to delete file'));
            await fileAdapter.deleteFile(filePath);
            expect(logger.warn).toHaveBeenCalledWith(`Deleting ${filePath} failed with error:Error: Failed to delete file`);
        });
    });
    describe('writeLogsToFile Tests', () => {
        it('should resolve successfully when given a valid file path and logs', async () => {
            const filePath = `${__dirname}/sample.txt`;
            const areLogsWritten = await fileAdapter.writeLogsToFile(filePath, [
                {
                    setup: 'done'
                }
            ]);
            expect(areLogsWritten).toStrictEqual(true);
            (0, rimraf_1.sync)(filePath);
        });
        it('should return error when no valid filePath exists', async () => {
            const filePath = '';
            await expect(() => fileAdapter.writeLogsToFile(filePath, [
                {
                    setup: 'done'
                }
            ])).rejects.toThrow('No valid file path exists');
        });
    });
    describe('clearTempFolder Tests', () => {
        it('should clear all the files present in the temp folder', async () => {
            const path = __dirname;
            jest.spyOn(node_os_1.default, 'tmpdir').mockReturnValueOnce(path);
            jest.spyOn(promises_1.default, 'readdir').mockResolvedValueOnce(['test', 'test2']);
            jest.spyOn(promises_1.default, 'stat').mockImplementation(async () => ({
                isFile: () => true
            }));
            const unlinkMock = jest.spyOn(promises_1.default, 'unlink');
            unlinkMock.mockResolvedValue();
            await fileAdapter.clearTempFolder();
            expect(promises_1.default.readdir).toHaveBeenCalledTimes(1);
            expect(promises_1.default.readdir).toHaveBeenCalledTimes(1);
            expect(promises_1.default.stat).toHaveBeenCalledTimes(TWO);
            expect(unlinkMock).toHaveBeenCalledTimes(TWO);
        });
    });
    describe('writeStreamToFile Tests', () => {
        it('should write streams to file', async () => {
            const filePath = `${__dirname}/sample.txt`;
            let messageWasSend = false;
            const mockEventStream = new node_stream_1.Readable({
                objectMode: false,
                read: function () {
                    if (!messageWasSend) {
                        messageWasSend = true;
                        this.push('hello');
                    }
                    return this.push(null);
                }
            });
            await fileAdapter.writeStreamToFile(filePath, mockEventStream);
            const fileContent = await readFileContent(filePath);
            const expectedContent = 'hello';
            expect(fileContent).toBe(expectedContent);
            (0, rimraf_1.sync)(filePath);
        });
    });
    describe('getReadStream', () => {
        it('should return a ReadableStream', () => {
            const filePath = __dirname;
            const stream = fileAdapter.getReadStream(filePath);
            expect(stream).toBeInstanceOf(node_fs_1.default.ReadStream);
        });
    });
});
//# sourceMappingURL=FileSystemAdapter.test.js.map